pub struct SbomTelemetry {
pub bsi_data: Option<Value>,
pub bsi_source: Option<String>,
pub e2_e_task_result: Option<String>,
pub parameters: Option<Configuration>,
pub result: Option<String>,
pub sbom_formats_used: Vec<SbomFile>,
pub switches: Option<Value>,
pub task_error_message: Option<String>,
pub task_name: Option<String>,
pub telemetry_id: Option<String>,
pub tool_execution_result: Option<i32>,
}Expand description
The telemetry that is logged to a file/console for the given SBOM execution.
Fields
bsi_data: Option<Value>All available bsi data from the task build execution which includes build and system environment variables like repository and build information.
bsi_source: Option<String>The source of the bsi data.
e2_e_task_result: Option<String>The end to end results of the extension task.
parameters: Option<Configuration>This holds the configuration for the ManifestTool. The values in this file are populated from the command line, config file and default.
result: Option<String>The result of the execution
sbom_formats_used: Vec<SbomFile>A list of the SBOM formats and related file properties that was used in the generation/validation of the SBOM.
switches: Option<Value>Any internal switches and their value that were used during the execution. A switch can be something that was provided through a configuraiton or an environment variable.
task_error_message: Option<String>Error messages that came from the extension task.
task_name: Option<String>The name of the task that logged SBOM telemetry
telemetry_id: Option<String>The unique id for this telemetry
tool_execution_result: Option<i32>The result of the tool as a numeric value.
Implementations
Sourceimpl SbomTelemetry
impl SbomTelemetry