Modules
Structs
- Audit
Action Info - Audit
Action Info List - Audit
LogEntry - Audit
LogQuery Result - The object returned when the audit log is queried. It contains the log and the information needed to query more audit entries.
- Audit
Stream - This class represents an audit stream
- Audit
Stream List - Decorated
Audit LogEntry - VssJson
Collection Wrapper - This class is used to serialize collections as a single JSON object on the wire.
- VssJson
Collection Wrapper Base