pub struct NewRetentionLease {
pub days_valid: Option<i32>,
pub definition_id: Option<i32>,
pub owner_id: Option<String>,
pub protect_pipeline: Option<bool>,
pub run_id: Option<i32>,
}Expand description
Required information to create a new retention lease.
Fields
days_valid: Option<i32>The number of days to consider the lease valid. A retention lease valid for more than 100 years (36500 days) will display as retaining the build “forever”.
definition_id: Option<i32>The pipeline definition of the run.
owner_id: Option<String>User-provided string that identifies the owner of a retention lease.
protect_pipeline: Option<bool>If set, this lease will also prevent the pipeline from being deleted while the lease is still valid.
run_id: Option<i32>The pipeline run to protect.
Implementations