pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list(
&self,
organization: impl Into<String>,
pool_id: i32,
) -> RequestBuilder
pub fn list( &self, organization: impl Into<String>, pool_id: i32, ) -> RequestBuilder
Get a list of agents.
Arguments:
organization: The name of the Azure DevOps organization.pool_id: The agent pool containing the agents
Sourcepub fn add(
&self,
organization: impl Into<String>,
body: impl Into<TaskAgent>,
pool_id: i32,
) -> RequestBuilder
pub fn add( &self, organization: impl Into<String>, body: impl Into<TaskAgent>, pool_id: i32, ) -> RequestBuilder
Adds an agent to a pool. You probably don’t want to call this endpoint directly. Instead, configure an agent using the agent download package.
Arguments:
organization: The name of the Azure DevOps organization.body: Details about the agent being addedpool_id: The agent pool in which to add the agent
Sourcepub fn get(
&self,
organization: impl Into<String>,
pool_id: i32,
agent_id: i32,
) -> RequestBuilder
pub fn get( &self, organization: impl Into<String>, pool_id: i32, agent_id: i32, ) -> RequestBuilder
Get information about an agent.
Arguments:
organization: The name of the Azure DevOps organization.pool_id: The agent pool containing the agentagent_id: The agent ID to get information about
Sourcepub fn replace_agent(
&self,
organization: impl Into<String>,
body: impl Into<TaskAgent>,
pool_id: i32,
agent_id: i32,
) -> RequestBuilder
pub fn replace_agent( &self, organization: impl Into<String>, body: impl Into<TaskAgent>, pool_id: i32, agent_id: i32, ) -> RequestBuilder
Replace an agent. You probably don’t want to call this endpoint directly. Instead, use the agent configuration script to remove and reconfigure an agent from your organization.
Arguments:
organization: The name of the Azure DevOps organization.body: Updated details about the replacing agentpool_id: The agent pool to useagent_id: The agent to replace
Sourcepub fn update(
&self,
organization: impl Into<String>,
body: impl Into<TaskAgent>,
pool_id: i32,
agent_id: i32,
) -> RequestBuilder
pub fn update( &self, organization: impl Into<String>, body: impl Into<TaskAgent>, pool_id: i32, agent_id: i32, ) -> RequestBuilder
Update agent details.
Arguments:
organization: The name of the Azure DevOps organization.body: Updated details about the agentpool_id: The agent pool to useagent_id: The agent to update
Sourcepub fn delete(
&self,
organization: impl Into<String>,
pool_id: i32,
agent_id: i32,
) -> RequestBuilder
pub fn delete( &self, organization: impl Into<String>, pool_id: i32, agent_id: i32, ) -> RequestBuilder
Delete an agent. You probably don’t want to call this endpoint directly. Instead, use the agent configuration script to remove an agent from your organization.
Arguments:
organization: The name of the Azure DevOps organization.pool_id: The pool ID to remove the agent fromagent_id: The agent ID to remove