pub struct ElasticPoolSettings {
pub agent_interactive_ui: Option<bool>,
pub azure_id: Option<String>,
pub desired_idle: Option<i32>,
pub max_capacity: Option<i32>,
pub max_saved_node_count: Option<i32>,
pub orchestration_type: Option<OrchestrationType>,
pub os_type: Option<OsType>,
pub recycle_after_each_use: Option<bool>,
pub service_endpoint_id: Option<String>,
pub service_endpoint_scope: Option<String>,
pub time_to_live_minutes: Option<i32>,
}Expand description
Class used for updating an elastic pool where only certain members are populated
Fields
agent_interactive_ui: Option<bool>Set whether agents should be configured to run with interactive UI
azure_id: Option<String>Azure string representing to location of the resource
desired_idle: Option<i32>Number of machines to have ready waiting for jobs
max_capacity: Option<i32>Maximum number of machines that will exist in the elastic pool
max_saved_node_count: Option<i32>Keep machines in the pool on failure for investigation
orchestration_type: Option<OrchestrationType>Operating system type of the machines in the pool
os_type: Option<OsType>Operating system type of the machines in the pool
recycle_after_each_use: Option<bool>Discard machines after each job completes
service_endpoint_id: Option<String>Id of the Service Endpoint used to connect to Azure
service_endpoint_scope: Option<String>Scope the Service Endpoint belongs to
time_to_live_minutes: Option<i32>The minimum time in minutes to keep idle agents alive
Implementations