pub struct TaskAgentAuthorization {
pub authorization_url: Option<String>,
pub client_id: Option<String>,
pub public_key: Option<TaskAgentPublicKey>,
}Expand description
Provides data necessary for authorizing the agent using OAuth 2.0 authentication flows.
Fields
Endpoint used to obtain access tokens from the configured token service.
client_id: Option<String>Client identifier for this agent.
public_key: Option<TaskAgentPublicKey>Represents the public key portion of an RSA asymmetric key.
Implementations