pub struct ClientContributionProviderDetails {
pub display_name: Option<String>,
pub name: Option<String>,
pub properties: Option<Value>,
pub version: Option<String>,
}Fields
display_name: Option<String>Friendly name for the provider.
name: Option<String>Unique identifier for this provider. The provider name can be used to cache the contribution data and refer back to it when looking for changes
properties: Option<Value>Properties associated with the provider
version: Option<String>Version of contributions associated with this contribution provider.
Implementations