pub struct GitAsyncRefOperationParameters {
pub generated_ref_name: Option<String>,
pub onto_ref_name: Option<String>,
pub repository: Option<GitRepository>,
pub source: Option<GitAsyncRefOperationSource>,
}Expand description
Parameters that are provided in the request body when requesting to cherry pick or revert.
Fields
generated_ref_name: Option<String>Proposed target branch name for the cherry pick or revert operation.
onto_ref_name: Option<String>The target branch for the cherry pick or revert operation.
repository: Option<GitRepository>source: Option<GitAsyncRefOperationSource>GitAsyncRefOperationSource specifies the pull request or list of commits to use when making a cherry pick and revert operation request. Only one should be provided.
Implementations