pub struct GitAsyncRefOperationSource {
pub commit_list: Vec<GitCommitRef>,
pub pull_request_id: Option<i32>,
}Expand description
GitAsyncRefOperationSource specifies the pull request or list of commits to use when making a cherry pick and revert operation request. Only one should be provided.
Fields
commit_list: Vec<GitCommitRef>A list of commits to cherry pick or revert
pull_request_id: Option<i32>Id of the pull request to cherry pick or revert
Implementations