pub struct GitImportGitSource {
pub overwrite: Option<bool>,
pub url: Option<String>,
}Expand description
Parameter for creating a git import request when source is Git version control
Fields
overwrite: Option<bool>Tells if this is a sync request or not
url: Option<String>Url for the source repo
Implementations