pub struct GitImportRequestParameters {
    pub delete_service_endpoint_after_import_is_done: Option<bool>,
    pub git_source: Option<GitImportGitSource>,
    pub service_endpoint_id: Option<String>,
    pub tfvc_source: Option<GitImportTfvcSource>,
}
Parameters for creating an import request

Fields

delete_service_endpoint_after_import_is_done: Option<bool>

Option to delete service endpoint when import is done

git_source: Option<GitImportGitSource>

Parameter for creating a git import request when source is Git version control

service_endpoint_id: Option<String>

Service Endpoint for connection to external endpoint

tfvc_source: Option<GitImportTfvcSource>

Parameter for creating a git import request when source is tfvc version control

Implementations