pub struct GitPullRequestMergeOptions {
pub conflict_authorship_commits: Option<bool>,
pub detect_rename_false_positives: Option<bool>,
pub disable_renames: Option<bool>,
}Expand description
The options which are used when a pull request merge is created.
Fields
If true, conflict resolutions applied during the merge will be put in separate commits to preserve authorship info for git blame, etc.
detect_rename_false_positives: Option<bool>disable_renames: Option<bool>If true, rename detection will not be performed during the merge.
Implementations