pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list(
&self,
organization: impl Into<String>,
repository_id: impl Into<String>,
pull_request_id: i32,
project: impl Into<String>,
) -> RequestBuilder
pub fn list( &self, organization: impl Into<String>, repository_id: impl Into<String>, pull_request_id: i32, project: impl Into<String>, ) -> RequestBuilder
Get a list of files attached to a given pull request.
Arguments:
organization: The name of the Azure DevOps organization.repository_id: The repository ID of the pull request’s target branch.pull_request_id: ID of the pull request.project: Project ID or project name
Sourcepub fn get(
&self,
organization: impl Into<String>,
file_name: impl Into<String>,
repository_id: impl Into<String>,
pull_request_id: i32,
project: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, organization: impl Into<String>, file_name: impl Into<String>, repository_id: impl Into<String>, pull_request_id: i32, project: impl Into<String>, ) -> RequestBuilder
Get the file content of a pull request attachment.
Arguments:
organization: The name of the Azure DevOps organization.file_name: The name of the attachment.repository_id: The repository ID of the pull request’s target branch.pull_request_id: ID of the pull request.project: Project ID or project name
Sourcepub fn create(
&self,
organization: impl Into<String>,
body: impl Into<String>,
file_name: impl Into<String>,
repository_id: impl Into<String>,
pull_request_id: i32,
project: impl Into<String>,
) -> RequestBuilder
pub fn create( &self, organization: impl Into<String>, body: impl Into<String>, file_name: impl Into<String>, repository_id: impl Into<String>, pull_request_id: i32, project: impl Into<String>, ) -> RequestBuilder
Attach a new file to a pull request.
Arguments:
organization: The name of the Azure DevOps organization.body: Stream to uploadfile_name: The name of the file.repository_id: The repository ID of the pull request’s target branch.pull_request_id: ID of the pull request.project: Project ID or project name
Sourcepub fn delete(
&self,
organization: impl Into<String>,
file_name: impl Into<String>,
repository_id: impl Into<String>,
pull_request_id: i32,
project: impl Into<String>,
) -> RequestBuilder
pub fn delete( &self, organization: impl Into<String>, file_name: impl Into<String>, repository_id: impl Into<String>, pull_request_id: i32, project: impl Into<String>, ) -> RequestBuilder
Delete a pull request attachment.
Arguments:
organization: The name of the Azure DevOps organization.file_name: The name of the attachment to delete.repository_id: The repository ID of the pull request’s target branch.pull_request_id: ID of the pull request.project: Project ID or project name