Module models

Module models 

Modules

avatar
graph_scope
graph_scope_creation_context
json_patch_operation

Structs

AadGraphMember
Avatar
GraphCachePolicies
GraphDescriptorResult
Subject descriptor of a Graph entity
GraphFederatedProviderData
Represents a set of data used to communicate with a federated provider on behalf of a particular user.
GraphGlobalExtendedPropertyBatch
GraphGroup
Graph group entity
GraphGroupCreationContext
Do not attempt to use this type to create a new group. This type does not contain sufficient fields to create a new group.
GraphGroupList
GraphGroupMailAddressCreationContext
Use this type to create a new group using the mail address as a reference to an existing group from an external AD or AAD backed provider. This is the subset of GraphGroup fields required for creation of a group for the AAD and AD use case.
GraphGroupOriginIdCreationContext
Use this type to create a new group using the OriginID as a reference to an existing group from an external AD or AAD backed provider. This is the subset of GraphGroup fields required for creation of a group for the AD and AAD use case.
GraphGroupVstsCreationContext
Use this type to create a new Vsts group that is not backed by an external provider.
GraphMember
GraphMembership
Relationship between a container and a member
GraphMembershipList
GraphMembershipState
Status of a Graph membership (active/inactive)
GraphMembershipTraversal
GraphProviderInfo
Who is the provider for this user and what is the identifier and domain that is used to uniquely identify the user.
GraphScope
Container where a graph entity is defined (organization, project, team)
GraphScopeCreationContext
This type is the subset of fields that can be provided by the user to create a Vsts scope. Scope creation is currently limited to internal back-compat scenarios. End users that attempt to create a scope with this API will fail.
GraphServicePrincipal
GraphServicePrincipalCreationContext
Do not attempt to use this type to create a new service principal. Use one of the subclasses instead. This type does not contain sufficient fields to create a new service principal.
GraphServicePrincipalList
GraphServicePrincipalOriginIdCreationContext
Use this type to create a new service principal using the OriginID as a reference to an existing service principal from an external AAD backed provider. This is the subset of GraphServicePrincipal fields required for creation of a GraphServicePrincipal for the AAD use case when looking up the service principal by its unique ID in the backing provider.
GraphServicePrincipalOriginIdUpdateContext
Use this type to update an existing service principal using the OriginID as a reference to an existing service principal from an external AAD backed provider. This is the subset of GraphServicePrincipal fields required for creation of a GraphServicePrincipal for AAD use case when looking up the service principal by its unique ID in the backing provider.
GraphServicePrincipalUpdateContext
Do not attempt to use this type to update service principal. Use one of the subclasses instead. This type does not contain sufficient fields to create a new service principal.
GraphStorageKeyResult
Storage key of a Graph entity
GraphSubject
Top-level graph entity
GraphSubjectBase
GraphSubjectList
GraphSubjectLookup
Batching of subjects to lookup using the Graph API
GraphSubjectLookupKey
GraphSubjectQuery
Subject to search using the Graph API
GraphSystemSubject
GraphUser
GraphUserCreationContext
Do not attempt to use this type to create a new user. Use one of the subclasses instead. This type does not contain sufficient fields to create a new user.
GraphUserList
GraphUserMailAddressCreationContext
Use this type to create a new user using the mail address as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its mail address in the backing provider.
GraphUserOriginIdCreationContext
Use this type to create a new user using the OriginID as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its unique ID in the backing provider.
GraphUserOriginIdUpdateContext
Use this type to update an existing user using the OriginID as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its unique ID in the backing provider.
GraphUserPrincipalNameCreationContext
Use this type to create a new user using the principal name as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its principal name in the backing provider.
GraphUserPrincipalNameUpdateContext
Use this type for transfering identity rights, for instance after performing a Tenant switch.
GraphUserUpdateContext
Do not attempt to use this type to update user. Use one of the subclasses instead. This type does not contain sufficient fields to create a new user.
IdentityMapping
IdentityMappings
JToken
Represents an abstract JSON token.
JsonPatchDocument
The JSON model for JSON Patch Operations
JsonPatchOperation
The JSON model for a JSON Patch operation
MappingResult
PagedGraphGroups
PagedGraphMembers
PagedGraphServicePrincipals
PagedGraphUsers
ReferenceLinks
The class to represent a collection of REST reference links.
RequestAccessPayLoad
ResolveDisconnectedUsersResponse
UserPrincipalName
VssJsonCollectionWrapper
This class is used to serialize collections as a single JSON object on the wire.
VssJsonCollectionWrapperBase