pub struct GraphGroupCreationContext {
pub storage_key: Option<String>,
}Expand description
Do not attempt to use this type to create a new group. This type does not contain sufficient fields to create a new group.
Fields
storage_key: Option<String>Optional: If provided, we will use this identifier for the storage key of the created group
Implementations