pub struct PagedGraphServicePrincipals {
pub continuation_token: Vec<String>,
pub graph_service_principals: Vec<GraphServicePrincipal>,
}Fields
continuation_token: Vec<String>This will be non-null if there is another page of data. There will never be more than one continuation token returned by a request.
graph_service_principals: Vec<GraphServicePrincipal>The enumerable list of service principals found within a page.
Implementations