pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn query(
&self,
organization: impl Into<String>,
body: impl Into<NotificationsQuery>,
) -> RequestBuilder
pub fn query( &self, organization: impl Into<String>, body: impl Into<NotificationsQuery>, ) -> RequestBuilder
Query for notifications. A notification includes details about the event, the request to and the response from the consumer service.
Arguments:
organization: The name of the Azure DevOps organization.
Sourcepub fn list(
&self,
organization: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list( &self, organization: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Get a list of notifications for a specific subscription. A notification includes details about the event, the request to and the response from the consumer service.
Arguments:
organization: The name of the Azure DevOps organization.subscription_id: ID for a subscription.
Sourcepub fn get(
&self,
organization: impl Into<String>,
subscription_id: impl Into<String>,
notification_id: i32,
) -> RequestBuilder
pub fn get( &self, organization: impl Into<String>, subscription_id: impl Into<String>, notification_id: i32, ) -> RequestBuilder
Get a specific notification for a subscription.
Arguments:
organization: The name of the Azure DevOps organization.subscription_id: ID for a subscription.
Sourcepub fn create(
&self,
organization: impl Into<String>,
body: impl Into<Notification>,
) -> RequestBuilder
pub fn create( &self, organization: impl Into<String>, body: impl Into<Notification>, ) -> RequestBuilder
Sends a test notification. This is useful for verifying the configuration of an updated or new service hooks subscription.
Arguments:
organization: The name of the Azure DevOps organization.