pub struct Artifact {
pub name: Option<String>,
pub signed_content: Option<SignedUrl>,
pub url: Option<String>,
}Expand description
Artifacts are collections of files produced by a pipeline. Use artifacts to share files between stages in a pipeline or between different pipelines.
Fields
name: Option<String>The name of the artifact.
signed_content: Option<SignedUrl>A signed url allowing limited-time anonymous access to private resources.
url: Option<String>Self-referential url
Implementations