pub struct ArtifactTriggerConfiguration {
pub is_trigger_supported: Option<bool>,
pub is_trigger_supported_only_in_hosted: Option<bool>,
pub is_webhook_supported_at_server_level: Option<bool>,
pub payload_hash_header_name: Option<String>,
pub resources: Option<Value>,
pub webhook_payload_mapping: Option<Value>,
}Fields
is_trigger_supported: Option<bool>Gets or sets the whether trigger is supported or not.
is_trigger_supported_only_in_hosted: Option<bool>Gets or sets the whether trigger is supported only on hosted environment.
is_webhook_supported_at_server_level: Option<bool>Gets or sets the whether webhook is supported at server level.
payload_hash_header_name: Option<String>Gets or sets the payload hash header name for the artifact trigger configuration.
resources: Option<Value>Gets or sets the resources for artifact trigger configuration.
webhook_payload_mapping: Option<Value>Gets or sets the webhook payload mapping for artifact trigger configuration.
Implementations