pub struct DeployPhase {
pub name: Option<String>,
pub phase_type: Option<PhaseType>,
pub rank: Option<i32>,
pub ref_name: Option<String>,
pub workflow_tasks: Vec<WorkflowTask>,
}Fields
name: Option<String>Gets and sets the name of deploy phase.
phase_type: Option<PhaseType>Indicates the deploy phase type.
rank: Option<i32>Gets and sets the rank of deploy phase.
ref_name: Option<String>Gets and sets the reference name of deploy phase.
workflow_tasks: Vec<WorkflowTask>Gets and sets the workflow tasks for the deploy phase.
Implementations
Sourceimpl DeployPhase
impl DeployPhase