Module models

Module models 

Modules

repository
setting_result

Structs

BoardResult
Defines the Board result that matched a Board search request.
BoardSearchRequest
Defines a Board search request.
BoardSearchResponse
Defines a Board search response item.
BranchInfo
Information about the configured branch.
CodeResult
Defines the code result containing information of the searched files and its metadata.
CodeSearchRequest
Defines a code search request.
CodeSearchResponse
Defines a code search response item.
Collection
Defines the details of the collection.
CustomRepositoryBranchStatusResponse
CustomRepositoryStatusResponse
Defines the custom repository status.
DepotInfo
Information about the custom repository indexing freshness for configured branches and depots.
EntitySearchRequest
Base contract for search request types without scroll support.
EntitySearchRequestBase
Base class for search request types.
EntitySearchResponse
Defines the base contract for search response.
FeedInfo
Defines the details of a feed.
Filter
Describes a filter bucket item representing the total matches of search result, name and id.
Hit
Describes the position of a piece of text in a document.
PackageHit
Defines the matched terms in the field of the package result.
PackageResult
Defines the package result that matched a package search request.
PackageSearchRequest
Defines a package search request.
PackageSearchResponse
PackageSearchResponseContent
Defines a response item that is returned for a package search request.
Project
Defines the details of the project.
ProjectReference
Defines the details of the project.
Repository
Defines the details of the repository.
RepositoryStatusResponse
Defines the repository status.
ScrollSearchRequest
Defines a scroll code search request.
SettingResult
Defines the setting result that matched a setting search request
SettingSearchRequest
Defines a setting search request
SettingSearchResponse
Defines a setting search response item
SortOption
Defines how to sort the result.
Team
Defines the details of the team.
TfvcRepositoryStatusResponse
Defines the TFVC repository status.
Version
Describes the details pertaining to a version of the result file.
Wiki
Defines the details of wiki.
WikiHit
Defines the matched terms in the field of the wiki result.
WikiResult
Defines the wiki result that matched a wiki search request.
WikiSearchRequest
Defines a wiki search request.
WikiSearchResponse
Defines a wiki search response item.
WorkItemHit
Defines the matched terms in the field of the work item result.
WorkItemResult
Defines the work item result that matched a work item search request.
WorkItemSearchRequest
Defines a work item search request.
WorkItemSearchResponse
Defines a response item that is returned for a work item search request.