pub struct DebugEntryCreateBatch {
pub create_behavior: Option<CreateBehavior>,
pub debug_entries: Vec<DebugEntry>,
pub proof_nodes: Vec<String>,
}Expand description
A batch of debug entry to create.
Fields
create_behavior: Option<CreateBehavior>Defines what to do when a debug entry in the batch already exists.
debug_entries: Vec<DebugEntry>The debug entries.
proof_nodes: Vec<String>Serialized Proof nodes, used to verify uploads on server side for Chunk Dedup DebugEntry
Implementations