pub struct CommentList {
pub work_item_tracking_resource: WorkItemTrackingResource,
pub comments: Vec<Comment>,
pub continuation_token: Option<String>,
pub count: Option<i32>,
pub next_page: Option<String>,
pub total_count: Option<i32>,
}Expand description
Represents a list of work item comments.
Fields
work_item_tracking_resource: WorkItemTrackingResourcecomments: Vec<Comment>List of comments in the current batch.
continuation_token: Option<String>A string token that can be used to retrieving next page of comments if available. Otherwise null.
count: Option<i32>The count of comments in the current batch.
next_page: Option<String>Uri to the next page of comments if it is available. Otherwise null.
total_count: Option<i32>Total count of comments on a work item.
Implementations
Sourceimpl CommentList
impl CommentList
pub fn new(work_item_tracking_resource: WorkItemTrackingResource) -> Self