pub struct PredefinedQuery {
pub has_more: Option<bool>,
pub id: Option<String>,
pub name: Option<String>,
pub results: Vec<WorkItem>,
pub url: Option<String>,
pub web_url: Option<String>,
}Expand description
Represents a single pre-defined query.
Fields
has_more: Option<bool>Whether or not the query returned the complete set of data or if the data was truncated.
id: Option<String>Id of the query
name: Option<String>Localized name of the query
results: Vec<WorkItem>The results of the query. This will be a set of WorkItem objects with only the ‘id’ set. The client is responsible for paging in the data as needed.
url: Option<String>REST API Url to use to retrieve results for this query
web_url: Option<String>Url to use to display a page in the browser with the results of this query
Implementations