pub struct ReorderOperation {
pub ids: Vec<i32>,
pub iteration_path: Option<String>,
pub next_id: Option<i32>,
pub parent_id: Option<i32>,
pub previous_id: Option<i32>,
}Expand description
Represents a reorder request for one or more work items.
Fields
ids: Vec<i32>IDs of the work items to be reordered. Must be valid WorkItem Ids.
iteration_path: Option<String>IterationPath for reorder operation. This is only used when we reorder from the Iteration Backlog
next_id: Option<i32>ID of the work item that should be after the reordered items. Can use 0 to specify the end of the list.
parent_id: Option<i32>Parent ID for all of the work items involved in this operation. Can use 0 to indicate the items don’t have a parent.
previous_id: Option<i32>ID of the work item that should be before the reordered items. Can use 0 to specify the beginning of the list.
Implementations