Modules
Structs
- Account
- Account
Create Info Internal - Account
List - Account
Preferences Internal - Properties
Collection - The class represents a property bag as a collection of key-value pairs. Values of all primitive types (any type with a
TypeCode != TypeCode.Object) except forDBNullare accepted. Values of type Byte[], Int32, Double, DateType and String preserve their type, other primitives are retuned as a String. Byte[] expected as base64 encoded string. - VssJson
Collection Wrapper - This class is used to serialize collections as a single JSON object on the wire.
- VssJson
Collection Wrapper Base