Modules
Structs
- AadGraph
Member - Avatar
- Graph
Cache Policies - Graph
Descriptor Result - Subject descriptor of a Graph entity
- Graph
Federated Provider Data - Represents a set of data used to communicate with a federated provider on behalf of a particular user.
- Graph
Global Extended Property Batch - Graph
Group - Graph group entity
- Graph
Group Creation Context - Do not attempt to use this type to create a new group. This type does not contain sufficient fields to create a new group.
- Graph
Group List - Graph
Group Mail Address Creation Context - Use this type to create a new group using the mail address as a reference to an existing group from an external AD or AAD backed provider. This is the subset of GraphGroup fields required for creation of a group for the AAD and AD use case.
- Graph
Group Origin IdCreation Context - Use this type to create a new group using the OriginID as a reference to an existing group from an external AD or AAD backed provider. This is the subset of GraphGroup fields required for creation of a group for the AD and AAD use case.
- Graph
Group Vsts Creation Context - Use this type to create a new Vsts group that is not backed by an external provider.
- Graph
Member - Graph
Membership - Relationship between a container and a member
- Graph
Membership List - Graph
Membership State - Status of a Graph membership (active/inactive)
- Graph
Membership Traversal - Graph
Provider Info - Who is the provider for this user and what is the identifier and domain that is used to uniquely identify the user.
- Graph
Scope - Container where a graph entity is defined (organization, project, team)
- Graph
Scope Creation Context - This type is the subset of fields that can be provided by the user to create a Vsts scope. Scope creation is currently limited to internal back-compat scenarios. End users that attempt to create a scope with this API will fail.
- Graph
Service Principal - Graph
Service Principal Creation Context - Do not attempt to use this type to create a new service principal. Use one of the subclasses instead. This type does not contain sufficient fields to create a new service principal.
- Graph
Service Principal List - Graph
Service Principal Origin IdCreation Context - Use this type to create a new service principal using the OriginID as a reference to an existing service principal from an external AAD backed provider. This is the subset of GraphServicePrincipal fields required for creation of a GraphServicePrincipal for the AAD use case when looking up the service principal by its unique ID in the backing provider.
- Graph
Service Principal Origin IdUpdate Context - Use this type to update an existing service principal using the OriginID as a reference to an existing service principal from an external AAD backed provider. This is the subset of GraphServicePrincipal fields required for creation of a GraphServicePrincipal for AAD use case when looking up the service principal by its unique ID in the backing provider.
- Graph
Service Principal Update Context - Do not attempt to use this type to update service principal. Use one of the subclasses instead. This type does not contain sufficient fields to create a new service principal.
- Graph
Storage KeyResult - Storage key of a Graph entity
- Graph
Subject - Top-level graph entity
- Graph
Subject Base - Graph
Subject List - Graph
Subject Lookup - Batching of subjects to lookup using the Graph API
- Graph
Subject Lookup Key - Graph
Subject Query - Subject to search using the Graph API
- Graph
System Subject - Graph
User - Graph
User Creation Context - Do not attempt to use this type to create a new user. Use one of the subclasses instead. This type does not contain sufficient fields to create a new user.
- Graph
User List - Graph
User Mail Address Creation Context - Use this type to create a new user using the mail address as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its mail address in the backing provider.
- Graph
User Origin IdCreation Context - Use this type to create a new user using the OriginID as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its unique ID in the backing provider.
- Graph
User Origin IdUpdate Context - Use this type to update an existing user using the OriginID as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its unique ID in the backing provider.
- Graph
User Principal Name Creation Context - Use this type to create a new user using the principal name as a reference to an existing user from an external AD or AAD backed provider. This is the subset of GraphUser fields required for creation of a GraphUser for the AD and AAD use case when looking up the user by its principal name in the backing provider.
- Graph
User Principal Name Update Context - Use this type for transfering identity rights, for instance after performing a Tenant switch.
- Graph
User Update Context - Do not attempt to use this type to update user. Use one of the subclasses instead. This type does not contain sufficient fields to create a new user.
- Identity
Mapping - Identity
Mappings - JToken
- Represents an abstract JSON token.
- Json
Patch Document - The JSON model for JSON Patch Operations
- Json
Patch Operation - The JSON model for a JSON Patch operation
- Mapping
Result - Paged
Graph Groups - Paged
Graph Members - Paged
Graph Service Principals - Paged
Graph Users - Reference
Links - The class to represent a collection of REST reference links.
- Request
Access PayLoad - Resolve
Disconnected Users Response - User
Principal Name - VssJson
Collection Wrapper - This class is used to serialize collections as a single JSON object on the wire.
- VssJson
Collection Wrapper Base