Modules
Structs
- Board
Result - Defines the Board result that matched a Board search request.
- Board
Search Request - Defines a Board search request.
- Board
Search Response - Defines a Board search response item.
- Branch
Info - Information about the configured branch.
- Code
Result - Defines the code result containing information of the searched files and its metadata.
- Code
Search Request - Defines a code search request.
- Code
Search Response - Defines a code search response item.
- Collection
- Defines the details of the collection.
- Custom
Repository Branch Status Response - Custom
Repository Status Response - Defines the custom repository status.
- Depot
Info - Information about the custom repository indexing freshness for configured branches and depots.
- Entity
Search Request - Base contract for search request types without scroll support.
- Entity
Search Request Base - Base class for search request types.
- Entity
Search Response - Defines the base contract for search response.
- Feed
Info - Defines the details of a feed.
- Filter
- Describes a filter bucket item representing the total matches of search result, name and id.
- Hit
- Describes the position of a piece of text in a document.
- Package
Hit - Defines the matched terms in the field of the package result.
- Package
Result - Defines the package result that matched a package search request.
- Package
Search Request - Defines a package search request.
- Package
Search Response - Package
Search Response Content - Defines a response item that is returned for a package search request.
- Project
- Defines the details of the project.
- Project
Reference - Defines the details of the project.
- Repository
- Defines the details of the repository.
- Repository
Status Response - Defines the repository status.
- Scroll
Search Request - Defines a scroll code search request.
- Setting
Result - Defines the setting result that matched a setting search request
- Setting
Search Request - Defines a setting search request
- Setting
Search Response - Defines a setting search response item
- Sort
Option - Defines how to sort the result.
- Team
- Defines the details of the team.
- Tfvc
Repository Status Response - Defines the TFVC repository status.
- Version
- Describes the details pertaining to a version of the result file.
- Wiki
- Defines the details of wiki.
- WikiHit
- Defines the matched terms in the field of the wiki result.
- Wiki
Result - Defines the wiki result that matched a wiki search request.
- Wiki
Search Request - Defines a wiki search request.
- Wiki
Search Response - Defines a wiki search response item.
- Work
Item Hit - Defines the matched terms in the field of the work item result.
- Work
Item Result - Defines the work item result that matched a work item search request.
- Work
Item Search Request - Defines a work item search request.
- Work
Item Search Response - Defines a response item that is returned for a work item search request.